LndHub
======

|PyPi| |License|

.. |PyPi| image:: https://badge.fury.io/py/lndhub.svg
   :target: https://pypi.python.org/pypi/lndhub/
.. |License| image:: https://img.shields.io/badge/license-MIT-blue.svg
   :target: LICENSE
